==> betr_1.0.0.tar.gz: betr/man/betr.Rd <==
\name{betr}
\alias{betr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Bayesian Estimation of Temporal Regulation (BETR): Calculate the probability of differential expression in time-course data }
\description{
Calculate the probability of differential expression of each feature in a microarray gene expression time-course data set. 
}
\usage{
betr(eset, cond=NULL, timepoint, replicate, twoColor = FALSE, twoCondition = NULL, alpha = 0.05, verbose=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{eset}{object of class matrix, ExpressionSet or exprSet containing log-ratios or log-values of expression for a series of microarrays}
  \item{cond}{character or factor vector giving the experimental group for each sample of eset. Not required for a single-condition time-course.}
  \item{timepoint}{numeric vector giving the time point for each sample of eset}
  \item{replicate}{character or factor vector giving the replicate ID of each sample of eset}
  \item{twoColor}{boolean indicating whether the data is from a two-color microarray platform}
  \item{twoCondition}{boolean indicating whether the data is from a two condition experiment (as opposed to a single condition experiment where the comparison is between baseline and subsequent time points)}
  \item{alpha}{the desired False Discovery Rate}
  \item{verbose}{whether to output more detailed information about the model fitting}
}
\details{
This function fits a model to estimate the probability of differential for each feature of time-course data set. 
}
\value{
a numeric vector of the probability of differential expression for each feature in the data set.
}
\references{The algorithm is described in detail in: (..undergoing review..)
}
\author{Martin Aryee}
\examples{
library(Biobase)    
data(timeEset)
prob <- betr(timeEset, cond=pData(timeEset)$strain, 
    timepoint=pData(timeEset)$time, replicate=pData(timeEset)$rep, alpha=0.05)
head(prob)
}

\keyword{ ts }

==> betr_1.8.0.tar.gz: betr/man/betr.Rd <==
\name{betr}
\alias{betr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Bayesian Estimation of Temporal Regulation (BETR): Calculate the probability of differential expression in time-course data }
\description{
Calculate the probability of differential expression of each feature in a microarray gene expression time-course data set. 
}
\usage{
betr(eset, cond=NULL, timepoint, replicate, twoColor = FALSE, twoCondition = NULL, alpha = 0.05, verbose=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{eset}{object of class matrix, ExpressionSet or exprSet containing log-ratios or log-values of expression for a series of microarrays}
  \item{cond}{character or factor vector giving the experimental group for each sample of eset. Not required for a single-condition time-course.}
  \item{timepoint}{numeric vector giving the time point for each sample of eset}
  \item{replicate}{character or factor vector giving the replicate ID of each sample of eset}
  \item{twoColor}{boolean indicating whether the data is from a two-color microarray platform}
  \item{twoCondition}{boolean indicating whether the data is from a two condition experiment (as opposed to a single condition experiment where the comparison is between baseline and subsequent time points)}
  \item{alpha}{the desired False Discovery Rate}
  \item{verbose}{whether to output more detailed information about the model fitting}
}
\details{
This function fits a model to estimate the probability of differential for each feature of time-course data set. 
}
\value{
a numeric vector of the probability of differential expression for each feature in the data set.
}
\references{The algorithm is described in detail in: Aryee et al., An improved empirical bayes approach to estimating differential gene expression in microarray time-course data: BETR (Bayesian Estimation of Temporal Regulation), BMC Bioinformatics. 2009 Dec 10;10:409.
}
\author{Martin Aryee}
\examples{
library(Biobase)    
data(timeEset)
prob <- betr(timeEset, cond=pData(timeEset)$strain, 
    timepoint=pData(timeEset)$time, replicate=pData(timeEset)$rep, alpha=0.05)
head(prob)
}

\keyword{ ts }
